@@ -1,5 +1,5 @@
 package Util::Medley::File;
-$Util::Medley::File::VERSION = '0.039';
+$Util::Medley::File::VERSION = '0.040';
 use Modern::Perl;
 use Moose;
 use namespace::autoclean;
@@ -24,7 +24,7 @@ Util::Medley::File - utility file methods
 
 =head1 VERSION
 
-version 0.039
+version 0.040
 
 =cut
 
@@ -1044,9 +1044,14 @@ multi method write (Str           :$path!,
 
 multi method write (Str           $path!, 
                     Str|ArrayRef  $content!,
-                    HashRef       $opts) {
-                    	
-    return $self->write(@_);
+                    HashRef       $opts?) {
+
+    my %a;
+    $a{path} = $path;
+    $a{content} = $content;
+    $a{opts} = $opts if $opts;
+                        	
+    return $self->write(%a);
 }
 
 
